@@ -1,12 +1,12 @@
-import inflect
 from functools import reduce
 from itertools import groupby
-from sqlalchemy import BigInteger
+from sqlalchemy import BigInteger, desc
 
 from sqlalchemy_api_handler.bases.accessor import Accessor
 from sqlalchemy_api_handler.bases.errors import ActivityError
 from sqlalchemy_api_handler.bases.save import Save
 from sqlalchemy_api_handler.utils.datum import relationships_in
+from sqlalchemy_api_handler.utils.logger import logger
 
 
 def merged_datum_from_activities(activities,
@@ -19,6 +19,15 @@ def merged_datum_from_activities(activities,
 
 
 class Activator(Save):
+
+    def __getattr__(self, key):
+        if key.endswith('ActivityUuid'):
+            relationship_name = key.split('ActivityUuid')[0]
+            relationship = getattr(self, relationship_name)
+            if hasattr(relationship.__class__, '__versioned__'):
+                return relationship.activityUuid
+        return Save.__getattr__(self, key)
+
     @classmethod
     def get_activity(cls):
         return Activator.activity_cls
@@ -52,16 +61,10 @@ class Activator(Save):
             if not entity_id:
                 entity = model(**relationships_in(first_activity.patch, model))
                 entity.activityUuid = uuid
-                Save.save(entity)
-                insert_activity = Activity.query.filter(
-                    (Activity.tableName == table_name) & \
-                    (Activity.data[id_key].astext.cast(BigInteger) == entity.id) & \
-                    (Activity.verb == 'insert')
-                ).one()
+                Activator.save(entity)
+                insert_activity = entity.insertActivity
                 insert_activity.dateCreated = first_activity.dateCreated
-                insert_activity.uuid = uuid
                 Save.save(insert_activity)
-
                 # want to make as if first_activity was the inser_activity one
                 # for such route like operations
                 # '''
@@ -79,6 +82,8 @@ class Activator(Save):
                 Activator.activate(*grouped_activities[1:])
                 continue
 
+
+
             min_date = min(map(lambda a: a.dateCreated, grouped_activities))
             already_activities_since_min_date = Activity.query \
                                                         .filter(
@@ -87,7 +92,6 @@ class Activator(Save):
                                                             (Activity.dateCreated >= min_date)
                                                         ) \
                                                         .all()
-
             Save.save(*grouped_activities)
             all_activities_since_min_date = sorted(already_activities_since_min_date + grouped_activities,
                                                    key=lambda activity: activity.dateCreated)
@@ -99,7 +103,7 @@ class Activator(Save):
             datum['activityUuid'] = uuid
             entity = model.query.get(entity_id)
             entity.modify(datum)
-            Save.save(entity)
+            Activator.save(entity)
 
     @classmethod
     def models(cls):
@@ -108,3 +112,22 @@ class Activator(Save):
         if Activity:
             models += [Activity]
         return models
+
+    @classmethod
+    def save(cls, *entities):
+        Activity = Activator.get_activity()
+        Save.save(*entities)
+        activities = []
+        for entity in entities:
+            if hasattr(entity, 'activityUuid'):
+                id_key = entity.__class__.id.property.key
+                last_activity = Activity.query.filter(
+                    (Activity.tableName == entity.__tablename__) & \
+                    (Activity.data[id_key].astext.cast(BigInteger) == entity.id)
+                ).order_by(desc(Activity.dateCreated)).limit(1).first()
+                if not last_activity and entity.__class__.__name__ == 'User':
+                    print('last_activity not found because activity not work with user for now...')
+                    continue
+                last_activity.uuid = entity.activityUuid
+                activities.append(last_activity)
+        Save.save(*activities)
